{% extends "base_template.html" %}

{% block title %}Reset password{% endblock %}

{% block content %}

<h1 class="h2 mb-3"><b>Forgot</b> password </h1>

<div class="row">
    <div class="col-md-6">
        <form action="{{ url_for('reset.forgot') }}" method="post">

            <div class="row">
                <div class="col-12">
                    <div class="form-group">
                        <label class="form-label" for="email">Email</label>
                        <input type="email" class="form-control" id="email" name="email" required>
                    </div>
                </div>
                <div class="col-12 mt-3">
                    <button type="submit" class="btn btn-primary">Reset Password</button>

                </div>
            </div>
            
        </form>
        {% with messages = get_flashed_messages(with_categories=true) %}
            {% if messages %}
                <div class="mt-3">
                    {% for category, message in messages %}
                        <div class="alert alert-{{ category }}">{{ message }}</div>
                    {% endfor %}
                </div>
            {% endif %}
        {% endwith %}
    </div>
</div>

{% endblock %}
