{% extends "base_template.html" %}

{% block title %}View reset{% endblock %}

{% block content %}

{% endblock %}

{% block scripts %}
    <script src="{{ url_for('reset.assets', subfolder='js', filename='scripts.js') }}"></script>
{% endblock %}